{ inputs, config, ... }:
{
  # But we all know I love zsh
  programs.zsh = {
    enable = true;
    enableAutosuggestions = true;
    enableCompletion = true;
    history.path = "${config.xdg.dataHome}/zsh/history";
    dotDir = ".config/zsh";
    envExtra = ''
      # NNN settings
      export NNN_FIFO="/tmp/nnn.fifo"
      export NNN_SSHFS="sshfs -o follow_symlinks"
      export NNN_TERMINAL="alacritty --class preview,preview"

      # Catppuccin colors nnn
      BLK="03" CHR="03" DIR="04" EXE="02" REG="07" HARDLINK="05" SYMLINK="05" MISSING="08" ORPHAN="01" FIFO="06" SOCK="03" UNKNOWN="01"
      export NNN_COLORS="#04020301;4231"
      export NNN_FCOLORS="$BLK$CHR$DIR$EXE$REG$HARDLINK$SYMLINK$MISSING$ORPHAN$FIFO$SOCK$UNKNOWN"
      '';      
    initExtra = ''
      # VI Mode escape timeout fix
      export KEYTIMEOUT=1
      
      # Substring search settings
      export HISTORY_SUBSTRING_SEARCH_HIGHLIGHT_FOUND="bg=blue,fg=black,bold"
      export HISTORY_SUBSTRING_SEARCH_HIGHLIGHT_NOT_FOUND='bg=red,fg=black,bold'
      bindkey -M vicmd 'k' history-substring-search-up
      bindkey -M vicmd 'j' history-substring-search-down
      '';
    initExtraFirst = ''
      nitch
      '';
    zplug = {
      enable = true;
      plugins = [
        { name = "zap-zsh/supercharge"; }
	    { name = "zap-zsh/completions"; }
	    { name = "zap-zsh/vim"; }
	    { name = "chivalryq/git-alias"; }
	    { name = "zdharma-continuum/fast-syntax-highlighting"; }
	    { name = "MichaelAquilina/zsh-you-should-use"; }
	    { name = "zsh-users/zsh-history-substring-search"; }
      ];
    };
  };

  # Eza settings
  programs.eza = {
    enable = true;
    enableAliases = true;
    git = true;
    icons = true;
  };

  # Zoxide settings
  programs.zoxide = {
    enable = true;
    enableZshIntegration = true;
  };

  # Starhip settings
  programs.starship = {
    enable = true;
    enableZshIntegration = true;
  };

  # Fzf settings
  programs.fzf = {
    enable = true;
    enableZshIntegration = true;
  };
}
